@@ -48,6 +48,19 @@
 #'   of function evaluations.
 #' @param max.features [\code{integer(1)}]\cr
 #'   Maximal number of features.
+#' @param tune.threshold [\code{logical(1)}]\cr
+#'   Should the threshold be tuned for the measure at hand, after each feature set evaluation,
+#'   via \code{\link{tuneThreshold}}?
+#'   Only works for classification if the predict type is \dQuote{prob}.
+#'   Default is \code{FALSE}.
+#' @param tune.threshold.args [\code{list}]\cr
+#'   Further arguments for threshold tuning that are passed down to \code{\link{tuneThreshold}}.
+#'   Default is none.
+#' @param log.fun [\code{function} | \code{NULL}]\cr
+#'   Function used for logging. If set to \code{NULL}, the internal default will be used.
+#'   Otherwise a function with arguments \code{learner}, \code{resampling}, \code{measures},
+#'   \code{par.set}, \code{control}, \code{opt.path}, \code{dob}, \code{x}, \code{y}, \code{remove.nas},
+#'   and \code{stage} is expected. See the implementation for details.
 #' @param prob [\code{numeric(1)}]\cr
 #'   Parameter of the random feature selection. Probability of choosing a feature.
 #' @param method [\code{character(1)}]\cr
@@ -86,32 +99,34 @@
 #' @aliases FeatSelControlExhaustive FeatSelControlRandom FeatSelControlSequential FeatSelControlGA
 NULL
 
-makeFeatSelControl = function(same.resampling.instance, impute.val = NULL, maxit, max.features, ..., cl) {
-  assertFlag(same.resampling.instance)
-  if (!is.null(impute.val))
-    assertNumber(impute.val)
+makeFeatSelControl = function(same.resampling.instance, impute.val = NULL, maxit, max.features,
+  tune.threshold = FALSE, tune.threshold.args = list(), log.fun = NULL, ..., cl) {
+
   maxit = asCount(maxit, na.ok = TRUE, positive = TRUE)
   max.features = asCount(max.features, na.ok = TRUE, positive = TRUE)
-  x = makeOptControl(same.resampling.instance = same.resampling.instance, impute.val = impute.val, ...)
+  if (is.null(log.fun))
+    log.fun = logFunFeatSel
+  x = makeOptControl(same.resampling.instance, impute.val, tune.threshold, tune.threshold.args, log.fun, ...)
   x$maxit = maxit
   x$max.features = max.features
   class(x) = c(cl, "FeatSelControl", class(x))
   return(x)
 }
 
-
 #' @export
 print.FeatSelControl = function(x, ...) {
   catf("FeatSel control: %s", class(x)[1])
   catf("Same resampling instance: %s", x$same.resampling.instance)
-  catf("Imputation value: %g", x$impute.val)
+  catf("Imputation value: %s", ifelse(is.null(x$impute.val), "<worst>", sprintf("%g", x$impute.val)))
   if (is.na(x$max.features))
     catf("Max. features: <not used>")
   else
     catf("Max. features: %i", x$max.features)
   catf("Max. iterations: %i", x$maxit)
+  catf("Tune threshold: %s", x$tune.threshold)
   if (length(x$extra.args))
     catf("Further arguments: %s", convertToShortString(x$extra.args))
   else
     catf("Further arguments: <not used>")
 }
+
