@@ -1,7 +1,8 @@
 makeOptWrapper = function(id, learner, resampling, measures, par.set, bit.names, bits.to.features,
-  control, show.info, cl) {
+  control, show.info, learner.subclass, model.subclass) {
 
-  x = makeBaseWrapper(id, learner, cl = c(cl, "OptWrapper"))
+  x = makeBaseWrapper(id, learner, learner.subclass = c(learner.subclass, "OptWrapper"),
+    model.subclass = model.subclass)
   x$resampling = resampling
   x$measures = measures
   x$opt.pars = par.set
@@ -13,15 +14,6 @@ makeOptWrapper = function(id, learner, resampling, measures, par.set, bit.names,
   return(x)
 }
 
-#' @export
-makeWrappedModel.OptWrapper = function(learner, learner.model, task.desc, subset, features, factor.levels, time) {
-  x = NextMethod()
-  if (inherits(learner, "TuneWrapper"))
-    addClasses(x, c("TuneModel", "OptModel"))
-  else
-    addClasses(x, c("FeatSelModel", "OptModel"))
-}
-
 #' @export
 print.OptModel = function(x, ...) {
   print.WrappedModel(x)
