@@ -25,9 +25,10 @@
 #'   parameters in \code{args}.
 #'   Default is empty set.
 #' @param par.vals [\code{list}]\cr
-#'   Named list of default values for params in \code{args} repectively \code{par.set}.
+#'   Named list of default values for params in \code{args} respectively \code{par.set}.
 #'   Default is empty list.
 #' @return [\code{\link{Learner}}].
+#' @family wrapper
 #' @export
 makePreprocWrapper = function(learner, train, predict, par.set = makeParamSet(), par.vals = list()) {
   learner = checkLearner(learner)
@@ -39,7 +40,8 @@ makePreprocWrapper = function(learner, train, predict, par.set = makeParamSet(),
     stop("'par.vals' must be a properly named list!")
 
   id = paste(learner$id, "preproc", sep = ".")
-  x = makeBaseWrapper(id, next.learner = learner, par.set = par.set, par.vals = par.vals, cl = "PreprocWrapper")
+  x = makeBaseWrapper(id, next.learner = learner, par.set = par.set, par.vals = par.vals,
+    learner.subclass = "PreprocWrapper", model.subclass = "PreprocModel")
   x$train = train
   x$predict = predict
   return(x)
