@@ -58,11 +58,11 @@ makeRLearnerInternal = function(id, type, package, par.set, par.vals, properties
   # must do that before accessing par.set
   # one case where lazy eval is actually helpful...
   assertCharacter(package, any.missing = FALSE)
-  requirePackages(package, paste("learner", id))
+  requirePackages(package, paste("learner", id), default.method = "load")
 
   assertString(id)
   assertChoice(type, choices = c("classif", "regr", "surv", "cluster"))
-  assertCharacter(properties, any.missing = FALSE)
+  assertSubset(properties, getSupportedLearnerProperties(type))
   assertClass(par.set, classes = "ParamSet")
   checkListElementClass(par.set$pars, "LearnerParam")
   assertList(par.vals)
