@@ -5,12 +5,14 @@ makeRLearner.classif.qda = function() {
     package = "MASS",
     par.set = makeParamSet(
       makeDiscreteLearnerParam(id = "method", default = "moment", values = c("moment", "mle", "mve", "t")),
-      makeNumericLearnerParam(id = "nu", default = 5 , lower = 2, requires = expression(method == "t"))
+      makeNumericLearnerParam(id = "nu", default = 5 , lower = 2, requires = expression(method == "t")),
+      makeDiscreteLearnerParam(id = "predict.method", values = c("plug-in", "predictive", "debiased"),
+        default = "plug-in", when = "predict")
     ),
     properties = c("twoclass", "multiclass", "numerics", "factors", "prob"),
     name = "Quadratic Discriminant Analysis",
     short.name = "qda",
-    note = ""
+    note = "Learner param 'predict.method' maps to 'method' in predict.lda."
   )
 }
 
@@ -21,8 +23,8 @@ trainLearner.classif.qda = function(.learner, .task, .subset, .weights = NULL,
 }
 
 #' @export
-predictLearner.classif.qda = function(.learner, .model, .newdata, ...) {
-  p = predict(.model$learner.model, newdata = .newdata, ...)
+predictLearner.classif.qda = function(.learner, .model, .newdata, predict.method = "plug-in", ...) {
+  p = predict(.model$learner.model, newdata = .newdata, method = predict.method, ...)
   if(.learner$predict.type == "response")
     return(p$class)
   else
