@@ -2,7 +2,7 @@
 makeRLearner.regr.crs = function() {
   makeRLearnerRegr(
     cl = "regr.crs",
-    package = "crs",
+    package = "!crs",
     par.set = makeParamSet(
       makeIntegerVectorLearnerParam(id = "degree", default = 3, lower = 0),
       makeIntegerVectorLearnerParam(id = "segments", default = 1, lower = 1),
@@ -46,9 +46,9 @@ makeRLearner.regr.crs = function() {
 trainLearner.regr.crs = function(.learner, .task, .subset, .weights = NULL,  ...) {
   f = getTaskFormula(.task)
   if (is.null(.weights)) {
-    crs::crs(f, data = getTaskData(.task, .subset), ...)
+    crs::crs(formula = f, data = getTaskData(.task, .subset), ...)
   } else  {
-    crs::crs(f, data = getTaskData(.task, .subset), weights = .weights, ...)
+    crs::crs(formula = f, data = getTaskData(.task, .subset), weights = .weights, ...)
   }
 }
 
