@@ -34,8 +34,21 @@
 #'   Should the same resampling instance be used for all evaluations to reduce variance?
 #'   Default is \code{TRUE}.
 #' @template arg_imputey
-#' @param start [\code{numeric}]\cr
+#' @param start [\code{list}]\cr
 #'   Named list of initial parameter values.
+#' @param tune.threshold [\code{logical(1)}]\cr
+#'   Should the threshold be tuned for the measure at hand, after each hyperparameter evaluation,
+#'   via \code{\link{tuneThreshold}}?
+#'   Only works for classification if the predict type is \dQuote{prob}.
+#'   Default is \code{FALSE}.
+#' @param tune.threshold.args [\code{list}]\cr
+#'   Further arguments for threshold tuning that are passed down to \code{\link{tuneThreshold}}.
+#'   Default is none.
+#' @param log.fun [\code{function} | \code{NULL}]\cr
+#'   Function used for logging. If set to \code{NULL}, the internal default will be used.
+#'   Otherwise a function with arguments \code{learner}, \code{resampling}, \code{measures},
+#'   \code{par.set}, \code{control}, \code{opt.path}, \code{dob}, \code{x}, \code{y}, \code{remove.nas},
+#'   and \code{stage} is expected. See the implementation for details.
 #' @param ... [any]\cr
 #'   Further control parameters passed to the \code{control} argument of \code{\link[cmaes]{cma_es}} and
 #'   \code{tunerConfig} argument of \code{\link[irace]{irace}}.
@@ -49,16 +62,14 @@
 #' @aliases TuneControlGrid TuneControlRandom TuneControlCMAES TuneControlGenSA TuneControlIrace
 NULL
 
-makeTuneControl = function(same.resampling.instance, impute.val = NULL, start = NULL, ..., cl) {
-  assertFlag(same.resampling.instance)
-  if (!is.null(impute.val))
-    assertNumber(impute.val)
-  if (!is.null(start)) {
-    assertList(start)
-    if (!isProperlyNamed(start))
-      stop("'start' must be a properly named list!")
-  }
-  x = makeOptControl(same.resampling.instance = same.resampling.instance, impute.val = impute.val, ...)
+makeTuneControl = function(same.resampling.instance, impute.val = NULL, start = NULL,
+  tune.threshold = FALSE, tune.threshold.args = list(), log.fun = NULL, ..., cl) {
+
+  if (!is.null(start))
+    assertList(start, min.len = 1L, names = "unique")
+  if (is.null(log.fun))
+    log.fun = logFunTune
+  x = makeOptControl(same.resampling.instance, impute.val, tune.threshold, tune.threshold.args, log.fun, ...)
   x$start = start
   addClasses(x, c(cl, "TuneControl"))
 }
@@ -67,7 +78,9 @@ makeTuneControl = function(same.resampling.instance, impute.val = NULL, start =
 print.TuneControl = function(x, ...) {
   catf("Tune control: %s", class(x)[1])
   catf("Same resampling instance: %s", x$same.resampling.instance)
-  catf("Imputation value: %g", x$impute.val)
+  catf("Imputation value: %s", ifelse(is.null(x$impute.val), "<worst>", sprintf("%g", x$impute.val)))
   catf("Start: %s", convertToShortString(x$start))
+  catf("Tune threshold: %s", x$tune.threshold)
   catf("Further arguments: %s", convertToShortString(x$extra.args))
 }
+
