@@ -4,20 +4,16 @@
 #' Replace all factor features with their dummy variables. Internally \code{\link{model.matrix}} is used.
 #' Non factor features will be left untouched and passed to the result.
 #'
-#' @param obj [\code{data.frame} | \code{\link{Task}}]\cr
-#'   Input data.
-#' @param target [\code{character()}]\cr
-#'   Name of the column(s) specifying the response.
-#'   Only used when \code{obj} is a data.frame, otherwise ignored.
+#' @template arg_taskdf
+#' @template arg_taskdf_target
 #' @param method [\code{character(1)}]\cr
 #'   Available are:\cr
 #'   \dQuote{1-of-n}: For n factor levels there will be n dummy variables.\cr
 #'   \dQuote{reference}: There will be n-1 dummy variables leaving out the first factor level of each variable.\cr
 #' @template arg_exclude
-#' @return [\code{data.frame} | \code{\link{Task}}]. Same type as
-#'   \code{obj}.
-#' @seealso \code{\link{model.matrix}}
+#' @template ret_taskdf
 #' @export
+#' @family eda_and_preprocess
 createDummyFeatures = function(obj, target = character(0L), method = "1-of-n", exclude = character(0L)) {
   assertChoice(method, choices = c("1-of-n", "reference"))
   assertCharacter(target)
@@ -29,9 +25,13 @@ createDummyFeatures = function(obj, target = character(0L), method = "1-of-n", e
 createDummyFeatures.data.frame = function(obj, target = character(0L), method = "1-of-n", exclude = character(0L)) {
   assertSubset(exclude, choices = colnames(obj))
   # extract obj to work on
-  work.cols = colnames(obj)[sapply(obj, is.factor)]
+  work.cols = colnames(obj)[vlapply(obj, is.factor)]
   work.cols = setdiff(work.cols, exclude)
   work.cols = setdiff(work.cols, target)
+  # prevent function model.matrix from dropping rows with missing values
+  old.na.action = options()$na.action
+  on.exit(options(na.action = old.na.action))
+  options(na.action = "na.pass")
   dummies = lapply(work.cols, function(colname) {
     if (method == "1-of-n") {
       form = paste0("~",colname,"-1")
