@@ -11,6 +11,18 @@
 #'
 #' If you want a measure for a misclassification cost matrix, look at \code{\link{makeCostMeasure}}.
 #' If you want to implement your own measure, look at \code{\link{makeMeasure}}.
+#'
+#' Most measures can directly be accessed via the function named after the scheme measureX (e.g. measureSSE).
+#' @param truth [\code{factor}]\cr
+#'   Vector of the true class.
+#' @param response [\code{factor}]\cr
+#'   Vector of the predicted class.
+#' @param negative [\code{character(1)}]\cr
+#'   The name of the negative class.
+#' @param positive [\code{character(1)}]\cr
+#'   The name of the positive class.
+#' @param probabilites [\code{numeric}]\cr
+#'   The probabilites for the positive class.
 #' @name measures
 #' @rdname measures
 #' @family performance
@@ -23,9 +35,9 @@ NULL
 #' @rdname measures
 #' @format none
 featperc = makeMeasure(id = "featperc", minimize = TRUE, best = 0, worst = 1,
-  properties = c("classif", "classif.multi", "regr", "surv", "costsens", "cluster"),
-  allowed.pred.types = c("response", "prob", "se"),
-  note = "Percentage of original features used for model, useful for feature selection.",
+  properties = c("classif", "classif.multi", "regr", "surv", "costsens", "cluster", "req.model", "req.pred"),
+  name = "Percentage of original features used for model",
+  note =  "Useful for feature selection.",
   fun = function(task, model, pred, feats, extra.args) {
     length(model$features) / sum(pred$task.desc$n.feat)
   }
@@ -35,9 +47,8 @@ featperc = makeMeasure(id = "featperc", minimize = TRUE, best = 0, worst = 1,
 #' @rdname measures
 #' @format none
 timetrain = makeMeasure(id = "timetrain", minimize = TRUE, best = 0, worst = Inf,
-  properties = c("classif", "classif.multi", "regr", "surv", "costsens", "cluster"),
-  allowed.pred.types = c("response", "prob", "se"),
-  note = "Time of fitting the model",
+  properties = c("classif", "classif.multi", "regr", "surv", "costsens", "cluster", "req.model"),
+  name = "Time of fitting the model",
   fun = function(task, model, pred, feats, extra.args) {
     model$time
   }
@@ -47,9 +58,8 @@ timetrain = makeMeasure(id = "timetrain", minimize = TRUE, best = 0, worst = Inf
 #' @rdname measures
 #' @format none
 timepredict = makeMeasure(id = "timepredict", minimize = TRUE, best = 0, worst = Inf,
-  properties = c("classif", "classif.multi", "regr", "surv", "costsens", "cluster"),
-  allowed.pred.types = c("response", "prob", "se"),
-  note = "Time of predicting test set",
+  properties = c("classif", "classif.multi", "regr", "surv", "costsens", "cluster", "req.pred"),
+  name = "Time of predicting test set",
   fun = function(task, model, pred, feats, extra.args) {
     pred$time
   }
@@ -59,9 +69,8 @@ timepredict = makeMeasure(id = "timepredict", minimize = TRUE, best = 0, worst =
 #' @rdname measures
 #' @format none
 timeboth = makeMeasure(id = "timeboth", minimize = TRUE, best = 0, worst = Inf,
-  properties = c("classif", "classif.multi", "regr", "surv", "costsens", "cluster"),
-  allowed.pred.types = c("response", "prob", "se"),
-  note = "timetrain + timepredict",
+  properties = c("classif", "classif.multi", "regr", "surv", "costsens", "cluster", "req.model", "req.pred"),
+  name = "timetrain + timepredict",
   fun = function(task, model, pred, feats, extra.args) {
     model$time + pred$time
   }
@@ -70,92 +79,135 @@ timeboth = makeMeasure(id = "timeboth", minimize = TRUE, best = 0, worst = Inf,
 ###############################################################################
 ### regression ###
 ###############################################################################
+
 #' @export sse
 #' @rdname measures
 #' @format none
 sse = makeMeasure(id = "sse", minimize = TRUE, best = 0, worst = Inf,
-  properties = "regr",
-  allowed.pred.types = c("response", "se"),
-  note = "Sum of squared errors",
+  properties = c("regr", "req.pred", "req.truth"),
+  name = "Sum of squared errors",
   fun = function(task, model, pred, feats, extra.args) {
-    sum((pred$data$response - pred$data$truth)^2)
+    measureSSE(pred$data$truth, pred$data$response)
   }
 )
 
+#' @export measureSSE
+#' @rdname measures
+#' @format none
+measureSSE = function(truth, response) {
+  sum((response - truth)^2)
+}
+
 #' @export mse
 #' @rdname measures
 #' @format none
 mse = makeMeasure(id = "mse", minimize = TRUE, best = 0, worst = Inf,
-  properties = "regr",
-  allowed.pred.types = c("response", "se"),
-  note = "Mean of squared errors",
+  properties = c("regr", "req.pred", "req.truth"),
+  name = "Mean of squared errors",
   fun = function(task, model, pred, feats, extra.args) {
-    mean((pred$data$response - pred$data$truth)^2)
+    measureMSE(pred$data$truth, pred$data$response)
   }
 )
 
+#' @export measureMSE
+#' @rdname measures
+#' @format none
+measureMSE = function(truth, response) {
+  mean((response - truth)^2)
+}
+
 #' @export rmse
 #' @format none
 #' @rdname measures
 #' @format none
 rmse = makeMeasure(id = "rmse", minimize = TRUE, best = 0, worst = Inf,
-  properties = "regr",
-  allowed.pred.types = c("response", "se"),
-  note = "Root mean square error",
+  properties = c("regr", "req.pred", "req.truth"),
+  name = "Root mean square error",
   fun = function(task, model, pred, feats, extra.args) {
-    mean((pred$data$response - pred$data$truth)^2)
+    measureRMSE(pred$data$truth, pred$data$response)
   },
   aggr = test.sqrt.of.mean
 )
 
+#' @export measureRMSE
+#' @rdname measures
+#' @format none
+measureRMSE = function(truth, response) {
+  sqrt(measureMSE(truth, response))
+}
+
 #' @export medse
 #' @rdname measures
 #' @format none
 medse = makeMeasure(id = "medse", minimize = TRUE, best = 0, worst = Inf,
-  properties = "regr",
-  allowed.pred.types = c("response", "se"),
-  note = "Median of squared errors",
+  properties = c("regr", "req.pred", "req.truth"),
+  name = "Median of squared errors",
   fun = function(task, model, pred, feats, extra.args) {
-    median((pred$data$response - pred$data$truth)^2)
+    measureMEDSE(pred$data$truth, pred$data$response)
   }
 )
 
+#' @export measureMEDSE
+#' @rdname measures
+#' @format none
+measureMEDSE = function(truth, response) {
+  median((response - truth)^2)
+}
+
 #' @export sae
 #' @rdname measures
 #' @format none
 sae = makeMeasure(id = "sae", minimize = TRUE, best = 0, worst = Inf,
-  properties = "regr",
-  allowed.pred.types = c("response", "se"),
-  note = "Sum of absolute errors",
+  properties = c("regr", "req.pred", "req.truth"),
+  name = "Sum of absolute errors",
   fun = function(task, model, pred, feats, extra.args) {
-    sum(abs(pred$data$response - pred$data$truth))
+    measureSAE(pred$data$truth, pred$data$response)
   }
 )
 
+#' @export measureSAE
+#' @rdname measures
+#' @format none
+measureSAE = function(truth, response) {
+  sum(abs(response - truth))
+}
+
 #' @export mae
 #' @rdname measures
 #' @format none
 mae = makeMeasure(id = "mae", minimize = TRUE, best = 0, worst = Inf,
-  properties = "regr",
-  allowed.pred.types = c("response", "se"),
-  note = "Mean of absolute errors",
+  properties = c("regr", "req.pred", "req.truth"),
+  name = "Mean of absolute errors",
   fun = function(task, model, pred, feats, extra.args) {
-    mean(abs(pred$data$response - pred$data$truth))
+    measureMAE(pred$data$truth, pred$data$response)
   }
 )
 
+#' @export measureMAE
+#' @rdname measures
+#' @format none
+measureMAE = function(truth, response) {
+  mean(abs(response - truth))
+}
+
 #' @export medae
 #' @rdname measures
 #' @format none
 medae = makeMeasure(id = "medae", minimize = TRUE, best = 0, worst = Inf,
-  properties = "regr",
-  allowed.pred.types = c("response", "se"),
-  note = "Median of absolute errors",
+  properties = c("regr", "req.pred", "req.truth"),
+  name = "Median of absolute errors",
   fun = function(task, model, pred, feats, extra.args) {
-    median(abs(pred$data$response - pred$data$truth))
+    measureMEDAE(pred$data$truth, pred$data$response)
   }
 )
 
+#' @export measureMEDAE
+#' @rdname measures
+#' @format none
+measureMEDAE = function(truth, response) {
+  median(abs(response - truth))
+}
+
 ###############################################################################
 ### classif multi ###
 ###############################################################################
@@ -163,33 +215,45 @@ medae = makeMeasure(id = "medae", minimize = TRUE, best = 0, worst = Inf,
 #' @rdname measures
 #' @format none
 mmce = makeMeasure(id = "mmce", minimize = TRUE, best = 0, worst = 1,
-  properties = c("classif", "classif.multi"),
-  allowed.pred.types = c("response", "prob"),
-  note = "Mean misclassification error",
+  properties = c("classif", "classif.multi", "req.pred", "req.truth"),
+  name = "Mean misclassification error",
   fun = function(task, model, pred, feats, extra.args) {
-    mean(pred$data$response != pred$data$truth)
+    measureMMCE(pred$data$truth, pred$data$response)
   }
 )
 
+#' @export measureMMCE
+#' @rdname measures
+#' @format none
+measureMMCE = function(truth, response) {
+  mean(response != truth)
+}
+
 #' @export acc
 #' @rdname measures
 #' @format none
 acc = makeMeasure(id = "acc", minimize = FALSE, best = 1, worst = 0,
-  properties = c("classif", "classif.multi"),
-  allowed.pred.types = c("response", "prob"),
-  note = "Accuracy",
+  properties = c("classif", "classif.multi", "req.pred", "req.truth"),
+  name = "Accuracy",
   fun = function(task, model, pred, feats, extra.args) {
-    mean(pred$data$response == pred$data$truth)
+    measureACC(pred$data$truth, pred$data$response)
   }
 )
 
+#' @export measureACC
+#' @rdname measures
+#' @format none
+measureACC = function(truth, response) {
+  mean(response == truth)
+}
+
 #' @export ber
 #' @rdname measures
 #' @format none
 ber = makeMeasure(id = "ber", minimize = TRUE, best = 0, worst = 1,
-  properties = c("classif", "classif.multi"),
-  allowed.pred.types = c("response", "prob"),
-  note = "Balanced error rate. Mean of misclassification error rates on all individual classes.",
+  properties = c("classif", "classif.multi", "req.pred", "req.truth"),
+  name = "Balanced error rate",
+  note = "Mean of misclassification error rates on all individual classes.",
   fun = function(task, model, pred, feats, extra.args) {
     n = length(pred$task.desc$class.levels) + 1L
     mean(getConfMatrix(pred, relative = TRUE)[-n, n])
@@ -200,19 +264,21 @@ ber = makeMeasure(id = "ber", minimize = TRUE, best = 0, worst = 1,
 #' @rdname measures
 #' @format none
 multiclass.auc = makeMeasure(id = "multiclass.auc", minimize = FALSE, best = 1, worst = 0,
-  properties = c("classif", "classif.multi"),
-  allowed.pred.types = c("response", "prob"),
-  note = "Area under the curve for multiclass problems. Calls `pROC::multiclass.roc`.",
+  properties = c("classif", "classif.multi", "req.pred", "req.truth", "req.prob"),
+  name = "Multiclass area under the curve",
+  note = "Calls `pROC::multiclass.roc`.",
   fun = function(task, model, pred, feats, extra.args) {
     # pROC does allow NAs
-    requirePackages("pROC", "multiclass.auc")
+    # FIXME: pROC seems not to mark auc() as S3method, which means that calling multiclass.roc wont find it in pRoc
+    # reported issue here:  https://github.com/xrobin/pROC/issues/4
+    requirePackages("!pROC", why = "multiclass.auc", default.method = "load")
     resp = pred$data$response
     predP = getProbabilities(pred)
     # choose the probablity of the choosen response
     predV = vnapply(seq_row(predP), function(i) {
       predP[i, resp[i]]
     })
-    auc = multiclass.roc(response = resp, predictor = predV)$auc
+    auc = pROC::multiclass.roc.default(response = resp, predictor = predV)$auc
     as.numeric(auc)
   }
 )
@@ -224,216 +290,327 @@ multiclass.auc = makeMeasure(id = "multiclass.auc", minimize = FALSE, best = 1,
 #' @rdname measures
 #' @format none
 auc = makeMeasure(id = "auc", minimize = FALSE, best = 1, worst = 0,
-  properties = "classif",
-  allowed.pred.types = "prob",
-  note = "Area under the curve",
+  properties = c("classif", "req.pred", "req.truth", "req.prob"),
+  name = "Area under the curve",
   fun = function(task, model, pred, feats, extra.args) {
     # ROCR does not work with NAs
     if (anyMissing(pred$data$response) || length(unique(pred$data$truth)) == 1L)
       return(NA_real_)
-    rpreds = asROCRPrediction(pred)
-    ROCR::performance(rpreds, "auc")@y.values[[1L]]
+    measureAUC(getProbabilities(pred), pred$data$truth, pred$task.desc$negative, pred$task.desc$positive)
   }
 )
 
+#' @export measureAUC
+#' @rdname measures
+#' @format none
+measureAUC = function(probabilites, truth, negative, positive) {
+  rpreds = asROCRPredictionIntern(probabilites, truth, negative, positive)
+  ROCR::performance(rpreds, "auc")@y.values[[1L]]
+}
+
 #' @export bac
 #' @rdname measures
 #' @format none
 bac = makeMeasure(id = "bac", minimize = FALSE, best = 1, worst = 0,
-  properties = c("classif"),
-  allowed.pred.types = c("response", "prob"),
-  note = "Balanced accuracy. Mean of true positive rate and true negative rate",
+  properties = c("classif", "req.pred", "req.truth"),
+  name = "Balanced accuracy",
+  note = "Mean of true positive rate and true negative rate.",
   fun = function(task, model, pred, feats, extra.args) {
     mean(c(tp$fun(pred = pred) / sum(pred$data$truth == pred$task.desc$positive),
            tn$fun(pred = pred) / sum(pred$data$truth == pred$task.desc$negative)))
   }
 )
 
+#' @export measureBAC
+#' @rdname measures
+#' @format none
+measureBAC = function(truth, response, negative, positive) {
+  mean(c(
+    measureTP(truth, response, positive) / sum(truth == positive),
+    measureTN(truth, response, negative) / sum(truth == negative)
+  ))
+}
+
 #' @export tp
 #' @rdname measures
 #' @format none
 tp = makeMeasure(id = "tp", minimize = FALSE, best = Inf, worst = 0,
-  properties = "classif",
-  allowed.pred.types = c("response", "prob"),
-  note = "True positives",
+  properties = c("classif", "req.pred", "req.truth"),
+  name = "True positives",
   fun = function(task, model, pred, feats, extra.args) {
-    sum(pred$data$truth == pred$data$response & pred$data$response == pred$task.desc$positive)
+    measureTP(pred$data$truth, pred$data$response, pred$task.desc$positive)
   }
 )
 
+#' @export measureTP
+#' @rdname measures
+#' @format none
+measureTP = function(truth, response, positive) {
+  sum(truth == response & response == positive)
+}
+
 #' @export tn
 #' @rdname measures
 #' @format none
 tn = makeMeasure(id = "tn", minimize = FALSE, best = Inf, worst = 0,
-  properties = "classif",
-  allowed.pred.types = c("response", "prob"),
-  note = "True negatives, also called correct rejections.",
+  properties = c("classif", "req.pred", "req.truth"),
+  name = "True negatives",
+  note = "Also called correct rejections.",
   fun = function(task, model, pred, feats, extra.args) {
-    sum(pred$data$truth == pred$data$response & pred$data$response == pred$task.desc$negative)
+    measureTN(pred$data$truth, pred$data$response, pred$task.desc$negative)
   }
 )
 
+#' @export measureTN
+#' @rdname measures
+#' @format none
+measureTN = function(truth, response, negative) {
+  sum(truth == response & response == negative)
+}
+
 #' @export fp
 #' @rdname measures
 #' @format none
 fp = makeMeasure(id = "fp", minimize = TRUE, best = 0, worst = Inf,
-  properties = "classif",
-  allowed.pred.types = c("response", "prob"),
-  note = "False positives, also called false alarms.",
+  properties = c("classif", "req.pred", "req.truth"),
+  name = "False positives",
+  note = "Also called false alarms.",
   fun = function(task, model, pred, feats, extra.args) {
-    sum(pred$data$truth != pred$data$response & pred$data$response == pred$task.desc$positive)
+    measureFP(pred$data$truth, pred$data$response, pred$task.desc$positive)
   }
 )
 
+#' @export measureFP
+#' @rdname measures
+#' @format none
+measureFP = function(truth, response, positive) {
+  sum(truth != response & response == positive)
+}
+
 #' @export fn
 #' @rdname measures
 #' @format none
 fn = makeMeasure(id = "fn", minimize = TRUE, best = 0, worst = Inf,
-  properties = "classif",
-  allowed.pred.types = c("response", "prob"),
-  note = "False negatives, also called misses.",
+  properties = c("classif", "req.pred", "req.truth"),
+  name = "False negatives",
+  note = "Also called misses.",
   fun = function(task, model, pred, feats, extra.args) {
-    sum(pred$data$truth != pred$data$response & pred$data$response == pred$task.desc$negative)
+    measureFN(pred$data$truth, pred$data$response, pred$task.desc$negative)
   }
 )
 
+#' @export measureFN
+#' @rdname measures
+#' @format none
+measureFN = function(truth, response, negative) {
+  sum(truth != response & response == negative)
+}
+
 #' @export tpr
 #' @rdname measures
 #' @format none
 tpr = makeMeasure(id = "tpr", minimize = FALSE, best = 1, worst = 0,
-  properties = "classif",
-  allowed.pred.types = c("response", "prob"),
-  note = "True positive rate, also called hit rate or recall.",
+  properties = c("classif", "req.pred", "req.truth"),
+  name = "True positive rate",
+  note = "Also called hit rate or recall.",
   fun = function(task, model, pred, feats, extra.args) {
-    tp$fun(pred = pred) / sum(pred$data$truth == pred$task.desc$positive)
+    measureTPR(pred$data$truth, pred$data$response, pred$task.desc$positive)
   }
 )
 
+#' @export measureTPR
+#' @rdname measures
+#' @format none
+measureTPR = function(truth, response, positive) {
+  measureTP(truth, response, positive) / sum(truth == positive)
+}
+
 #' @export tnr
 #' @rdname measures
 #' @format none
 tnr = makeMeasure(id = "tnr", minimize = FALSE, best = 1, worst = 0,
-  properties = "classif",
-  allowed.pred.types = c("response", "prob"),
- 	note = "True negative rate. Also called specificity.",
+  properties = c("classif", "req.pred", "req.truth"),
+  name = "True negative rate",
+  note = "Also called specificity.",
   fun = function(task, model, pred, feats, extra.args) {
-    tn$fun(pred = pred) / sum(pred$data$truth == pred$task.desc$negative)
+    measureTNR(pred$data$truth, pred$data$response, pred$task.desc$negative)
   }
 )
 
+#' @export measureTNR
+#' @rdname measures
+#' @format none
+measureTNR = function(truth, response, negative) {
+  measureTN(truth, response, negative) / sum(truth == negative)
+}
+
 #' @export fpr
 #' @rdname measures
 #' @format none
 fpr = makeMeasure(id = "fpr", minimize = TRUE, best = 0, worst = 1,
-  properties = "classif",
-  allowed.pred.types = c("response", "prob"),
- 	note = "False positive rate, also called false alarm rate or fall-out.",
+  properties = c("classif", "req.pred", "req.truth"),
+  name = "False positive rate",
+  note = "Also called false alarm rate or fall-out.",
   fun = function(task, model, pred, feats, extra.args) {
-    fp$fun(pred = pred) / sum(pred$data$truth == pred$task.desc$negative)
+    measureFPR(pred$data$truth, pred$data$response, pred$task.desc$negative, pred$task.desc$positive)
   }
 )
 
+#' @export measureFPR
+#' @rdname measures
+#' @format none
+measureFPR = function(truth, response, negative, positive) {
+  measureFP(truth, response, positive) / sum(truth == negative)
+}
+
 #' @export fnr
 #' @rdname measures
 #' @format none
 fnr = makeMeasure(id = "fnr", minimize = TRUE, best = 0, worst = 1,
-  properties = "classif",
-  allowed.pred.types = c("response", "prob"),
-  note = "False negative rate",
+  properties = c("classif", "req.pred", "req.truth"),
+  name = "False negative rate",
   fun = function(task, model, pred, feats, extra.args) {
-    fn$fun(pred = pred) / sum(pred$data$truth == pred$task.desc$positive)
+    measureFNR(pred$data$truth, pred$data$response, pred$task.desc$negative, pred$task.desc$positive)
   }
 )
 
+#' @export measureFNR
+#' @rdname measures
+#' @format none
+measureFNR = function(truth, response, negative, positive) {
+  measureFN(truth, response, negative) / sum(truth == positive)
+}
+
 #' @export ppv
 #' @rdname measures
 #' @format none
 ppv = makeMeasure(id = "ppv", minimize = FALSE, best = 1, worst = 0,
-  properties = "classif",
-  allowed.pred.types = c("response", "prob"),
-  note = "Positive predictive value, also called precision.",
+  properties = c("classif", "req.pred", "req.truth"),
+  name = "Positive predictive value",
+  note = "Also called precision.",
   fun = function(task, model, pred, feats, extra.args) {
-    tp$fun(pred = pred) / sum(pred$data$response == pred$task.desc$positive)
+    measurePPV(pred$data$truth, pred$data$response, pred$task.desc$positive)
   }
 )
 
+#' @export measurePPV
+#' @rdname measures
+#' @format none
+measurePPV = function(truth, response, positive) {
+  measureTP(truth, response, positive) / sum(response == positive)
+}
+
 #' @export npv
 #' @rdname measures
 #' @format none
 npv = makeMeasure(id = "npv", minimize = FALSE, best = 1, worst = 0,
-  properties = "classif",
-  allowed.pred.types = c("response", "prob"),
-  note = "Negative predictive value",
+  properties = c("classif", "req.pred", "req.truth"),
+  name = "Negative predictive value",
   fun = function(task, model, pred, feats, extra.args) {
-    tn$fun(pred = pred) / sum(pred$data$response == pred$task.desc$negative)
+    measureNPV(pred$data$truth, pred$data$response, pred$task.desc$negative)
   }
 )
 
+#' @export measureNPV
+#' @rdname measures
+#' @format none
+measureNPV = function(truth, response, negative) {
+  measureTN(truth, response, negative) / sum(response == negative)
+}
+
 #' @export fdr
 #' @rdname measures
 #' @format none
 fdr = makeMeasure(id = "fdr", minimize = TRUE, best = 0, worst = 1,
-  properties = "classif",
-  allowed.pred.types = c("response", "prob"),
-  note = "False discovery rate",
+  properties = c("classif", "req.pred", "req.truth"),
+  name = "False discovery rate",
   fun = function(task, model, pred, feats, extra.args) {
-    fp$fun(pred = pred) / sum(pred$data$response == pred$task.desc$positive)
+    measureFDR(pred$data$truth, pred$data$response, pred$task.desc$positive)
   }
 )
 
+#' @export measureFDR
+#' @rdname measures
+#' @format none
+measureFDR = function(truth, response, positive) {
+  measureFP(truth, response, positive) / sum(response == positive)
+}
+
 #' @export mcc
 #' @rdname measures
 #' @format none
 mcc = makeMeasure(id = "mcc", minimize = FALSE,
-  properties = "classif",
-  allowed.pred.types = c("response", "prob"), best = 1, worst = -1,
-  note = "Matthews correlation coefficient",
+  properties = c("classif", "req.pred", "req.truth"), best = 1, worst = -1,
+  name = "Matthews correlation coefficient",
   fun = function(task, model, pred, feats, extra.args) {
-    (tp$fun(pred = pred) *
-    tn$fun(pred = pred) -
-    fp$fun(pred = pred) *
-    fn$fun(pred = pred)) /
-    sqrt(prod(table(pred$data$truth, pred$data$response)))
+    measureMCC(pred$data$truth, pred$data$response, pred$task.desc$negative, pred$task.desc$positive)
   }
 )
 
+#' @export measureMCC
+#' @rdname measures
+#' @format none
+measureMCC = function(truth, response, negative, positive) {
+  tn = measureTN(truth, response, negative)
+  tp = measureTP(truth, response, positive)
+  fn = measureFN(truth, response, negative)
+  fp = measureFP(truth, response, positive)
+  (tp * tn - fp * fn) / sqrt(prod(table(truth, response)))
+}
+
 #' @export f1
 #' @rdname measures
 #' @format none
 f1 = makeMeasure(id = "f1", minimize = FALSE, best = 1, worst = 0,
-  properties = "classif",
-  allowed.pred.types = c("response", "prob"),
-  note = "F1 measure",
+  properties = c("classif", "req.pred", "req.truth"),
+  name = "F1 measure",
   fun = function(task, model, pred, feats, extra.args) {
-    2 * tp$fun(pred = pred) /
-      (sum(pred$data$truth == pred$task.desc$positive) + sum(pred$data$response == pred$task.desc$positive))
+    measureF1(pred$data$truth, pred$data$response, pred$task.desc$positive)
   }
 )
 
+measureF1 = function(truth, response, positive) {
+  2 * measureTP(truth, response, positive) /
+    (sum(truth == positive) + sum(response == positive))
+}
+
 #' @export gmean
 #' @rdname measures
 #' @format none
 gmean = makeMeasure(id = "gmean", minimize = FALSE, best = 1, worst = 0,
-  properties = "classif",
-  allowed.pred.types = c("response", "prob"),
-  note = "G-mean, geometric mean of recall and specificity.",
+  properties = c("classif", "req.pred", "req.truth"),
+  name = "G-mean",
+  note = "Geometric mean of recall and specificity.",
   fun = function(task, model, pred, feats, extra.args) {
-    sqrt(tpr$fun(pred = pred) * tnr$fun(pred = pred))
+    measureGMEAN(pred$data$truth, pred$data$response, pred$task.desc$negative, pred$task.desc$positive)
   }
 )
 
+#' @export measureGMEAN
+#' @rdname measures
+#' @format none
+measureGMEAN = function(truth, response, negative, positive) {
+  sqrt(measureTP(truth, response, positive) * measureTN(truth, response, negative))
+}
+
 #' @export gpr
 #' @rdname measures
 #' @format none
 gpr = makeMeasure(id = "gpr", minimize = FALSE, best = 1, worst = 0,
-  properties = "classif",
-  allowed.pred.types = c("response", "prob"),
-  note = "Geometric mean of precision and recall",
+  properties = c("classif", "req.pred", "req.truth"),
+  name = "Geometric mean of precision and recall",
   fun = function(task, model, pred, feats, extra.args) {
-    sqrt(ppv$fun(pred = pred) * tpr$fun(pred = pred))
+    measureGPR(pred$data$truth, pred$data$response, pred$task.desc$positive)
   }
 )
 
+#' @export measureGPR
+#' @rdname measures
+#' @format none
+measureGPR = function(truth, response, positive) {
+  sqrt(measurePPV(truth, response, positive) * measureTPR(truth, response, positive))
+}
+
 ###############################################################################
 ### survival ###
 ###############################################################################
@@ -441,14 +618,16 @@ gpr = makeMeasure(id = "gpr", minimize = FALSE, best = 1, worst = 0,
 #' @rdname measures
 #' @format none
 cindex = makeMeasure(id = "cindex", minimize = FALSE, best = 1, worst = 0,
-  properties = "surv",
-  allowed.pred.types = c("response", "prob"),
-  note = "Concordance index",
+  properties = c("surv", "req.pred", "req.truth"),
+  name = "Concordance index",
   fun = function(task, model, pred, feats, extra.args) {
-    requirePackages("Hmisc")
-    # FIXME: we need to ensure the censoring here
+    requirePackages("Hmisc", default.method = "load")
+    resp = pred$data$response
+    if (anyMissing(resp))
+      return(NA_real_)
+    # FIXME: we need to convert to he correct survival type
     s = Surv(pred$data$truth.time, pred$data$truth.event)
-    rcorr.cens(-1 * pred$data$response, s)[["C Index"]]
+    Hmisc::rcorr.cens(-1 * resp, s)[["C Index"]]
   }
 )
 
@@ -458,9 +637,8 @@ cindex = makeMeasure(id = "cindex", minimize = FALSE, best = 1, worst = 0,
 #' @export meancosts
 #' @rdname measures
 meancosts = makeMeasure(id = "meancosts", minimize = TRUE, best = 0, worst = Inf,
-  properties = "costsens",
-  allowed.pred.types = "response",
-  note = "Mean costs of the predicted choices.",
+  properties = c("costsens", "req.pred", "req.task"),
+  name = "Mean costs of the predicted choices",
   fun = function(task, model, pred, feats, extra.args) {
     classes = as.character(pred$data$response)
     ids = pred$data$id
@@ -475,9 +653,9 @@ meancosts = makeMeasure(id = "meancosts", minimize = TRUE, best = 0, worst = Inf
 #' @export mcp
 #' @rdname measures
 mcp = makeMeasure(id = "mcp", minimize = TRUE, best = 0, worst = Inf,
-  properties = "costsens",
-  allowed.pred.types = "response",
-  note = "Misclassification penalty, i.e. average difference between costs of oracle and model prediction.",
+  properties = c("costsens", "req.pred", "req.task"),
+  name = "Misclassification penalty",
+  note = "Average difference between costs of oracle and model prediction.",
   fun = function(task, model, pred, feats, extra.args) {
     mc = meancosts$fun(task, NULL, pred, NULL, extra.args)
     oc = mean(apply(task$env$costs, 1L, min))
@@ -492,12 +670,12 @@ mcp = makeMeasure(id = "mcp", minimize = TRUE, best = 0, worst = Inf,
 #' @rdname measures
 #' @format none
 db = makeMeasure(id = "db", minimize = TRUE, best = 0, worst = Inf,
-  properties = "cluster",
-  allowed.pred.types = c("response", "prob"),
-  note = "Davies-Bouldin cluster separation measure, see `?clusterSim::index.DB`",
+  properties = c("cluster", "req.pred", "req.feats"),
+  name = "Davies-Bouldin cluster separation measure",
+  note ="See `?clusterSim::index.DB`.",
   fun = function(task, model, pred, feats, extra.args) {
-    requirePackages("clusterSim")
-    index.DB(feats, pred$data$response)$DB
+    requirePackages("clusterSim", default.method = "load")
+    clusterSim::index.DB(feats, pred$data$response)$DB
   }
 )
 
@@ -505,12 +683,12 @@ db = makeMeasure(id = "db", minimize = TRUE, best = 0, worst = Inf,
 #' @rdname measures
 #' @format none
 dunn = makeMeasure(id = "dunn", minimize = FALSE, best = Inf, worst = 0,
-  properties = "cluster",
-  allowed.pred.types = c("response", "prob"),
-  note = "Dunn index, see `?clValid::dunn`",
+  properties = c("cluster", "req.pred", "req.feats"),
+  name = "Dunn index",
+  note = "See `?clValid::dunn`.",
   fun = function(task, model, pred, feats, extra.args) {
-    requirePackages("clValid")
-    dunn(Data = feats, clusters = pred$data$response)
+    requirePackages("clValid", default.method = "load")
+    clValid::dunn(Data = feats, clusters = pred$data$response)
   }
 )
 
@@ -518,12 +696,12 @@ dunn = makeMeasure(id = "dunn", minimize = FALSE, best = Inf, worst = 0,
 #' @rdname measures
 #' @format none
 G1 = makeMeasure(id = "G1", minimize = FALSE, best = Inf, worst = 0,
-  properties = "cluster",
-  allowed.pred.types = c("response", "prob"),
-  note = "Calinski-Harabasz pseudo F statistic, see `?clusterSim::index.G1`",
+  properties = c("cluster", "req.pred", "req.feats"),
+  name = "Calinski-Harabasz pseudo F statistic",
+  note = "See `?clusterSim::index.G1`.",
   fun = function(task, model, pred, feats, extra.args) {
-    requirePackages("clusterSim")
-    index.G1(feats, pred$data$response)
+    requirePackages("clusterSim", default.method = "load")
+    clusterSim::index.G1(feats, pred$data$response)
   }
 )
 
@@ -531,12 +709,12 @@ G1 = makeMeasure(id = "G1", minimize = FALSE, best = Inf, worst = 0,
 #' @rdname measures
 #' @format none
 G2 = makeMeasure(id = "G2", minimize = FALSE, best = Inf, worst = 0,
-  properties = "cluster",
-  allowed.pred.types = c("response", "prob"),
-  note = "Baker and Hubert adaptation of Goodman-Kruskal's gamma statistic, see `?clusterSim::index.G2`",
+  properties = c("cluster", "req.pred", "req.feats"),
+  name = "Baker and Hubert adaptation of Goodman-Kruskal's gamma statistic",
+  note = "See `?clusterSim::index.G2`.",
   fun = function(task, model, pred, feats, extra.args) {
-    requirePackages("clusterSim")
-    index.G2(dist.GDM(feats), pred$data$response)
+    requirePackages("clusterSim", default.method = "load")
+    clusterSim::index.G2(clusterSim::dist.GDM(feats), pred$data$response)
   }
 )
 
@@ -544,12 +722,12 @@ G2 = makeMeasure(id = "G2", minimize = FALSE, best = Inf, worst = 0,
 #' @rdname measures
 #' @format none
 silhouette = makeMeasure(id = "silhouette", minimize = FALSE, best = Inf, worst = 0,
-  properties = "cluster",
-  allowed.pred.types = c("response", "prob"),
-  note = "Rousseeuw's silhouette internal cluster quality index, see `?clusterSim::index.S`",
+  properties = c("cluster", "req.pred", "req.feats"),
+  name = "Rousseeuw's silhouette internal cluster quality index",
+  note = "See `?clusterSim::index.S`.",
   fun = function(task, model, pred, feats, extra.args) {
-    requirePackages("clusterSim")
-    index.S(dist.GDM(feats), pred$data$response)
+    requirePackages("clusterSim", default.method = "load")
+    clusterSim::index.S(clusterSim::dist.GDM(feats), pred$data$response)
   }
 )
 
