@@ -1,6 +1,5 @@
 tuneCMAES = function(learner, task, resampling, measures, par.set, control, opt.path, show.info) {
-
-  requirePackages("cmaes", "tune_cmaes")
+  requirePackages("cmaes", "tune_cmaes", default.method = "load")
 
   low = getLower(par.set)
   upp = getUpper(par.set)
@@ -17,7 +16,7 @@ tuneCMAES = function(learner, task, resampling, measures, par.set, control, opt.
   ctrl.cmaes = insert(ctrl.cmaes, control$extra.args)
   cx = function(x) convertXMatrixCols(x, par.set)
 
-  or = cmaes::cma_es(par = start, fn = tunerFitnFunVectorized, lower = low, upper = upp, control = ctrl.cmaes,
+  cmaes::cma_es(par = start, fn = tunerFitnFunVectorized, lower = low, upper = upp, control = ctrl.cmaes,
     learner = learner, task = task, resampling = resampling, measures = measures,
     par.set = par.set, ctrl = control, opt.path = opt.path, show.info = show.info,
     convertx = cx, remove.nas = FALSE)
