@@ -1,5 +1,5 @@
-library(mlbench)
-data(Sonar, BreastCancer)
+data(Sonar, package = "mlbench")
+data(BreastCancer, package = "mlbench")
 
 binaryclass.df = Sonar
 binaryclass.formula = Class~.
@@ -29,14 +29,15 @@ noclass.train = noclass.df[noclass.train.inds, ]
 noclass.test  = noclass.df[noclass.test.inds, ]
 noclass.task = makeClusterTask("noclass", data = noclass.df)
 
-data(BostonHousing)
+data(BostonHousing, package = "mlbench")
 regr.df = BostonHousing
 regr.formula = medv ~ .
 regr.target = "medv"
-regr.train.inds = seq(1, 506, 3)
+regr.train.inds = seq(1, 506, 7)
 regr.test.inds  = setdiff(1:nrow(regr.df), regr.train.inds)
 regr.train = regr.df[regr.train.inds, ]
 regr.test  = regr.df[regr.test.inds, ]
+regr.class.col = 14
 regr.task = makeRegrTask("regrtask", data = regr.df, target = regr.target)
 
 regr.num.df = regr.df[,sapply(regr.df, is.numeric)]
@@ -46,6 +47,7 @@ regr.num.train.inds = regr.train.inds
 regr.num.test.inds  = regr.test.inds
 regr.num.train = regr.num.df[regr.num.train.inds, ]
 regr.num.test  = regr.num.df[regr.num.test.inds, ]
+regr.num.class.col = 13
 regr.num.task = makeRegrTask("regrnumtask", data = regr.num.df, target = regr.num.target)
 
 surv.df = cbind(time = rexp(150, 1/20)+1, event = sample(c(TRUE, FALSE), 150, replace = TRUE), iris)
