@@ -14,8 +14,8 @@ test_that("performance", {
   res = makeResampleDesc("CV", iters = 3)
   r = resample(lrn, task = binaryclass.task, resampling = res)
 
-  mymeasure = makeMeasure(id="mym", minimize=TRUE, properties = c("classif", "classif.multi"), allowed.pred.types = c("response"),
-    fun=function(task, model, pred, feats, extra.args) {
+  mymeasure = makeMeasure(id = "mym", minimize = TRUE, properties = c("classif", "classif.multi", "predtype.response"),
+    fun = function(task, model, pred, feats, extra.args) {
       # normal test error
       e1 = mean(pred$data$truth != pred$data$response)
       # we do this manually
@@ -36,10 +36,22 @@ test_that("performance", {
 
   # custom measure
 
-  mymeasure = makeCustomResampledMeasure(id = "mym", fun = function(task, group, pred, feats, extra.args) {
-    mean(pred$data$truth != pred$data$response)
-  })
+  mymeasure = makeCustomResampledMeasure(id = "mym", properties = c("classif", "predtype.response"),
+    fun = function(task, group, pred, feats, extra.args) {
+      mean(pred$data$truth != pred$data$response)
+    })
   rdesc = makeResampleDesc("Holdout")
   r = resample(lrn, binaryclass.task, rdesc, measures = list(mmce, mymeasure))
   expect_equal(as.numeric(r$aggr["mmce.test.mean"]), as.numeric(r$aggr["custom.mym"]))
 })
+
+
+test_that("performance checks for missing truth col", {
+  lrn = makeLearner("classif.rpart", predict.type = "prob")
+  m = train(lrn, binaryclass.task)
+  test.x = getTaskData(binaryclass.task, target.extra = TRUE)$data
+  pred = predict(m, newdata = test.x)
+
+  expect_error(performance(pred, measure = mmce), "need to have a 'truth' col")
+})
+
