@@ -1,16 +1,16 @@
 context("classif_LiblineaRMultiClass")
 
 test_that("classif_LiblineaRMultiClass", {
-  library(LiblineaR)
-  
+  requirePackages("LiblineaR", default.method = "load")
+
   set.seed(getOption("mlr.debug.seed"))
-  m = LiblineaR(data=multiclass.train[, -multiclass.class.col],
+  m = LiblineaR::LiblineaR(data=multiclass.train[, -multiclass.class.col],
                 labels=multiclass.train[, multiclass.target],
                 type=4)
   p = predict(m, newx=multiclass.test[, -multiclass.class.col])
   old.predicts = as.factor(p$predictions)
-  
+
   testSimple("classif.LiblineaRMultiClass", multiclass.df,
              multiclass.target, multiclass.train.inds, old.predicts)
-  
+
 })
