@@ -8,8 +8,12 @@ test_that("FilterWrapper", {
   expect_equal(m$features, getTaskFeatureNames(binaryclass.task))
   lrn2 = makeFilterWrapper(lrn1, fw.method = "chi.squared", fw.abs = 0L)
   m = train(lrn2, binaryclass.task)
+  expect_equal(getLeafModel(m)$features, character(0))
+  expect_true(inherits(getLeafModel(m)$learner.model, "NoFeaturesModel"))
   lrn2 = makeFilterWrapper(lrn1, fw.method = "chi.squared", fw.perc = 0.1)
   res = makeResampleDesc("CV", iters = 2)
   r = resample(lrn2, binaryclass.task, res)
   expect_true(!any(is.na(r$aggr)))
 })
+
+
