@@ -1,7 +1,7 @@
 context("regr_IBk")
 
 test_that("regr_IBk", {
-  library(RWeka)
+  requirePackages("RWeka", default.method = "load")
   parset.list = list(
     list(),
     list(K = 2)
@@ -11,11 +11,11 @@ test_that("regr_IBk", {
 
   for (i in 1:length(parset.list)) {
     parset = parset.list[[i]]
-    ctrl = do.call(Weka_control, parset)
+    ctrl = do.call(RWeka::Weka_control, parset)
     pars = list(regr.formula, data = regr.train)
     pars = c(pars, parset)
     set.seed(getOption("mlr.debug.seed"))
-    m =  IBk(regr.formula, regr.train, control = ctrl)
+    m =  RWeka::IBk(regr.formula, regr.train, control = ctrl)
     set.seed(getOption("mlr.debug.seed"))
     p = predict(m, newdata = regr.test)
     old.predicts.list[[i]] = p
