@@ -1,7 +1,7 @@
 context("regr_ctree")
 
 test_that("regr_ctree", {
-  library(party)
+  requirePackages("party", default.method = "load")
   parset.list = list(
     list(),
     list(minsplit = 10, mincriterion = 0.005),
@@ -16,11 +16,11 @@ test_that("regr_ctree", {
     parset = parset.list[[i]]
     ctrl = do.call(ctree_control, parset)
     set.seed(getOption("mlr.debug.seed"))
-    m = ctree(formula = regr.formula, data = regr.train, control = ctrl)
+    m = party::ctree(formula = regr.formula, data = regr.train, control = ctrl)
     p  = predict(m, newdata = regr.test, type = "response")[, 1L]
     old.predicts.list[[i]] = p
   }
 
-  testSimpleParsets("regr.ctree", regr.df, regr.target, regr.train.inds, 
+  testSimpleParsets("regr.ctree", regr.df, regr.target, regr.train.inds,
     old.predicts.list, parset.list)
-})
\ No newline at end of file
+})
