@@ -1,7 +1,6 @@
 context("tuneIrace")
 
 test_that("tuneIrace", {
-  library(irace)
   rdesc = makeResampleDesc("Holdout", stratify = TRUE, split = 0.1)
   ps1 = makeParamSet(
     makeNumericParam("cp", lower = 0.001, upper = 1),
@@ -55,4 +54,30 @@ test_that("tuneIrace works with dependent params", {
 
 })
 
+# we had a bug here
+test_that("tuneIrace works with logical params", {
+  ps = makeParamSet(
+    makeLogicalParam("scaled")
+  )
+  lrn = makeLearner("classif.ksvm", kernel = "vanilladot")
+  rdesc = makeResampleDesc("Holdout", split = 0.3, stratify = TRUE)
+  ctrl = makeTuneControlIrace(maxExperiments = 20, nbIterations = 1, minNbSurvival = 1)
+  task = subsetTask(multiclass.task, c(1:10, 50:60, 100:110))
+  tr = tuneParams(lrn, task, rdesc, par.set = ps, control = ctrl)
+  expect_true(getOptPathLength(tr$opt.path) >= 15 && getOptPathLength(tr$opt.path) <= 20)
+  expect_true(!is.na(tr$y))
 
+  lrn2 = makeTuneWrapper(lrn, rdesc, par.set = ps, control = ctrl)
+  z = holdout(lrn2, task, split = 0.5, stratify = TRUE)
+  expect_true(getOptPathLength(tr$opt.path) >= 15 && getOptPathLength(tr$opt.path) <= 20)
+  expect_true(!is.na(tr$y))
+})
+
+test_that("tuneIrace works with tune.threshold", {
+  rdesc = makeResampleDesc("Holdout", stratify = TRUE, split = 0.1)
+  ps = makeParamSet(makeIntegerParam("minsplit", lower = 1, upper = 3))
+
+  n = 40
+  ctrl = makeTuneControlIrace(maxExperiments = n, nbIterations = 2, minNbSurvival = 1)
+  tr = tuneParams("classif.rpart", multiclass.task, rdesc, par.set = ps, control = ctrl)
+})
